@@ -2,16 +2,12 @@
 from onyx_client.data.device_mode import DeviceMode
 from onyx_client.data.numeric_value import NumericValue
 from onyx_client.device.device import Device
-from onyx_client.enum.action import Action
 from onyx_client.enum.device_type import DeviceType
 
 
 # not mapped properties:
 # - auto_calibration
-# - drivetime_down
-# - drivetime_up
 # - heart_beat_enabled
-# - rotationtime
 # - sun_guard_lower_action
 # - sun_guard_lower_angle
 # - sun_guard_lower_position
@@ -20,8 +16,6 @@ from onyx_client.enum.device_type import DeviceType
 # - sun_guard_upper_angle
 # - sun_guard_upper_position
 # - sun_guard_upper_threshold
-# - switch_button_direction
-# - switch_drive_direction
 # - system_state
 # - wind_guard_enabled
 # - wind_peak_threshold
@@ -34,7 +28,7 @@ class Shutter(Device):
         name: str,
         device_type: DeviceType,
         device_mode: DeviceMode,
-        actions: list[Action],
+        actions: list,
         target_position: NumericValue = None,
         target_angle: NumericValue = None,
         actual_angle: NumericValue = None,
@@ -48,3 +42,31 @@ class Shutter(Device):
         self.target_angle = target_angle
         self.actual_angle = actual_angle
         self.actual_position = actual_position
+
+    def update_with(self, update):
+        super().update_with(update)
+
+        self.target_position = (
+            self.target_position
+            if update.target_position is None
+            else update.target_position
+        )
+        self.target_angle = (
+            self.target_angle if update.target_angle is None else update.target_angle
+        )
+        self.actual_angle.update_with(update.actual_angle)
+        self.actual_position.update_with(update.actual_position)
+
+    @staticmethod
+    def keys() -> list:
+        return [
+            "target_position",
+            "target_angle",
+            "actual_angle",
+            "actual_position",
+            "drivetime_down",
+            "drivetime_up",
+            "rotationtime",
+            "switch_button_direction",
+            "switch_drive_direction",
+        ]
